@@ -7,6 +7,7 @@ import (
 	"os"
 	"regexp"
 	"strings"
+	"sync"
 	"time"
 
 	"github.com/aws/aws-sdk-go/aws"
@@ -32,6 +33,8 @@ var openedStreams = prometheus.NewGaugeVec(
 	[]string{"group"},
 )
 
+var streamIndexMutex = sync.Mutex{}
+
 var linesRead = prometheus.NewCounterVec(
 	prometheus.CounterOpts{
 		Name: "cs_cloudwatch_stream_hits_total",
@@ -68,6 +71,7 @@ type CloudwatchSourceConfiguration struct {
 	AwsProfile                        *string        `yaml:"aws_profile,omitempty"`
 	PrependCloudwatchTimestamp        *bool          `yaml:"prepend_cloudwatch_timestamp,omitempty"`
 	AwsConfigDir                      *string        `yaml:"aws_config_dir,omitempty"`
+	AwsRegion                         *string        `yaml:"aws_region,omitempty"`
 }
 
 //LogStreamTailConfig is the configuration for one given stream within one group
@@ -94,7 +98,7 @@ var (
 	def_StreamReadTimeout       = 10 * time.Minute
 	def_PollDeadStreamInterval  = 10 * time.Second
 	def_GetLogEventsPagesLimit  = int64(1000)
-	def_AwsConfigDir            = "/root/.aws/"
+	def_AwsConfigDir            = ""
 )
 
 func (cw *CloudwatchSource) Configure(cfg []byte, logger *log.Entry) error {
@@ -148,20 +152,28 @@ func (cw *CloudwatchSource) Configure(cfg []byte, logger *log.Entry) error {
 		cw.Config.AwsConfigDir = &def_AwsConfigDir
 	}
 	logger.Tracef("aws_config_dir set to %s", *cw.Config.AwsConfigDir)
-	_, err := os.Stat(*cw.Config.AwsConfigDir)
-	if os.IsNotExist(err) {
-		logger.Errorf("aws_config_dir '%s' : directory does not exists", *cw.Config.AwsConfigDir)
-		return fmt.Errorf("aws_config_dir %s does not exist", *cw.Config.AwsConfigDir)
+	if *cw.Config.AwsConfigDir != "" {
+		_, err := os.Stat(*cw.Config.AwsConfigDir)
+		if err != nil {
+			logger.Errorf("can't read aws_config_dir '%s' got err %s", *cw.Config.AwsConfigDir, err)
+			return fmt.Errorf("can't read aws_config_dir %s got err %s ", *cw.Config.AwsConfigDir, err)
+		}
+		os.Setenv("AWS_SDK_LOAD_CONFIG", "1")
+		//as aws sdk relies on $HOME, let's allow the user to override it :)
+		os.Setenv("AWS_CONFIG_FILE", fmt.Sprintf("%s/config", *cw.Config.AwsConfigDir))
+		os.Setenv("AWS_SHARED_CREDENTIALS_FILE", fmt.Sprintf("%s/credentials", *cw.Config.AwsConfigDir))
+	} else {
+		if cw.Config.AwsRegion == nil {
+			logger.Errorf("aws_region is not specified, specify it or aws_config_dir")
+			return fmt.Errorf("aws_region is not specified, specify it or aws_config_dir")
+		}
+		os.Setenv("AWS_REGION", *cw.Config.AwsRegion)
 	}
-	os.Setenv("AWS_SDK_LOAD_CONFIG", "1")
-	//as aws sdk relies on $HOME, let's allow the user to override it :)
-	os.Setenv("AWS_CONFIG_FILE", fmt.Sprintf("%s/config", *cw.Config.AwsConfigDir))
-	os.Setenv("AWS_SHARED_CREDENTIALS_FILE", fmt.Sprintf("%s/credentials", *cw.Config.AwsConfigDir))
+
 	if err := cw.newClient(); err != nil {
 		return err
 	}
 	cw.streamIndexes = make(map[string]string)
-
 	if cw.Config.StreamRegexp != nil {
 		if _, err := regexp.Compile(*cw.Config.StreamRegexp); err != nil {
 			return errors.Wrapf(err, "error while compiling regexp '%s'", *cw.Config.StreamRegexp)
@@ -329,7 +341,7 @@ func (cw *CloudwatchSource) LogStreamManager(in chan LogStreamTailConfig, outCha
 			}
 
 			if cw.Config.StreamRegexp != nil {
-				match, err := regexp.Match(newStream.StreamName, []byte(*cw.Config.StreamRegexp))
+				match, err := regexp.Match(*cw.Config.StreamRegexp, []byte(newStream.StreamName))
 				if err != nil {
 					cw.logger.Warningf("invalid regexp : %s", err)
 				} else {
@@ -366,14 +378,16 @@ func (cw *CloudwatchSource) LogStreamManager(in chan LogStreamTailConfig, outCha
 				cw.monitoredStreams = append(cw.monitoredStreams, &newStream)
 			}
 		case <-pollDeadStreamInterval.C:
+			newMonitoredStreams := cw.monitoredStreams[:0]
 			for idx, stream := range cw.monitoredStreams {
 				if !cw.monitoredStreams[idx].t.Alive() {
 					cw.logger.Debugf("remove dead stream %s", stream.StreamName)
 					openedStreams.With(prometheus.Labels{"group": cw.monitoredStreams[idx].GroupName}).Dec()
-					cw.monitoredStreams = append(cw.monitoredStreams[:idx], cw.monitoredStreams[idx+1:]...)
-					break
+				} else {
+					newMonitoredStreams = append(newMonitoredStreams, stream)
 				}
 			}
+			cw.monitoredStreams = newMonitoredStreams
 		case <-cw.t.Dying():
 			cw.logger.Infof("LogStreamManager for %s is dying, %d alive streams", cw.Config.GroupName, len(cw.monitoredStreams))
 			for idx, stream := range cw.monitoredStreams {
@@ -383,10 +397,9 @@ func (cw *CloudwatchSource) LogStreamManager(in chan LogStreamTailConfig, outCha
 					if err := cw.monitoredStreams[idx].t.Wait(); err != nil {
 						cw.logger.Debugf("error while waiting for death of %s : %s", stream.StreamName, err)
 					}
-				} else {
-					cw.monitoredStreams = append(cw.monitoredStreams[:idx], cw.monitoredStreams[idx+1:]...)
 				}
 			}
+			cw.monitoredStreams = nil
 			cw.logger.Debugf("routine cleanup done, return")
 			return nil
 		}
@@ -396,14 +409,14 @@ func (cw *CloudwatchSource) LogStreamManager(in chan LogStreamTailConfig, outCha
 func (cw *CloudwatchSource) TailLogStream(cfg *LogStreamTailConfig, outChan chan types.Event) error {
 	var startFrom *string
 	var lastReadMessage time.Time = time.Now()
-	startup := true
-
 	ticker := time.NewTicker(cfg.PollStreamInterval)
 	//resume at existing index if we already had
-	if v, ok := cw.streamIndexes[cfg.GroupName+"+"+cfg.StreamName]; ok && v != "" {
+	streamIndexMutex.Lock()
+	v := cw.streamIndexes[cfg.GroupName+"+"+cfg.StreamName]
+	streamIndexMutex.Unlock()
+	if v != "" {
 		cfg.logger.Debugf("restarting on index %s", v)
 		startFrom = &v
-		startup = false
 	}
 	/*during first run, we want to avoid reading any message, but just get a token.
 	if we don't, we might end up sending the same item several times. hence the 'startup' hack */
@@ -414,27 +427,23 @@ func (cw *CloudwatchSource) TailLogStream(cfg *LogStreamTailConfig, outChan chan
 			hasMorePages := true
 			for hasMorePages {
 				/*for the first call, we only consume the last item*/
-				limit := cfg.GetLogEventsPagesLimit
-				if startup {
-					limit = 1
-				}
 				cfg.logger.Tracef("calling GetLogEventsPagesWithContext")
 				ctx := context.Background()
 				err := cw.cwClient.GetLogEventsPagesWithContext(ctx,
 					&cloudwatchlogs.GetLogEventsInput{
-						Limit:         aws.Int64(limit),
+						Limit:         aws.Int64(cfg.GetLogEventsPagesLimit),
 						LogGroupName:  aws.String(cfg.GroupName),
 						LogStreamName: aws.String(cfg.StreamName),
 						NextToken:     startFrom,
+						StartFromHead: aws.Bool(true),
 					},
 					func(page *cloudwatchlogs.GetLogEventsOutput, lastPage bool) bool {
 						cfg.logger.Tracef("%d results, last:%t", len(page.Events), lastPage)
 						startFrom = page.NextForwardToken
 						if page.NextForwardToken != nil {
+							streamIndexMutex.Lock()
 							cw.streamIndexes[cfg.GroupName+"+"+cfg.StreamName] = *page.NextForwardToken
-						}
-						if startup { //we grab the NextForwardToken and we return on first iteration
-							return false
+							streamIndexMutex.Unlock()
 						}
 						if lastPage { /*wait another ticker to check on new log availability*/
 							cfg.logger.Tracef("last page")
@@ -451,7 +460,6 @@ func (cw *CloudwatchSource) TailLogStream(cfg *LogStreamTailConfig, outChan chan
 								cfg.logger.Debugf("pushing message : %s", evt.Line.Raw)
 								linesRead.With(prometheus.Labels{"group": cfg.GroupName, "stream": cfg.StreamName}).Inc()
 								outChan <- evt
-
 							}
 						}
 						return true
@@ -462,11 +470,7 @@ func (cw *CloudwatchSource) TailLogStream(cfg *LogStreamTailConfig, outChan chan
 					cfg.logger.Warningf("err : %s", newerr)
 					return newerr
 				}
-				if startup {
-					startup = false
-				}
 				cfg.logger.Tracef("done reading GetLogEventsPagesWithContext")
-
 				if time.Since(lastReadMessage) > cfg.StreamReadTimeout {
 					cfg.logger.Infof("%s/%s reached timeout (%s) (last message was %s)", cfg.GroupName, cfg.StreamName, time.Since(lastReadMessage),
 						lastReadMessage)
@@ -480,7 +484,7 @@ func (cw *CloudwatchSource) TailLogStream(cfg *LogStreamTailConfig, outChan chan
 	}
 }
 
-func (cw *CloudwatchSource) ConfigureByDSN(dsn string, logtype string, logger *log.Entry) error {
+func (cw *CloudwatchSource) ConfigureByDSN(dsn string, labels map[string]string, logger *log.Entry) error {
 	cw.logger = logger
 
 	dsn = strings.TrimPrefix(dsn, cw.GetName()+"://")
@@ -494,9 +498,7 @@ func (cw *CloudwatchSource) ConfigureByDSN(dsn string, logtype string, logger *l
 	}
 	cw.Config.GroupName = frags[0]
 	cw.Config.StreamName = &frags[1]
-	cw.Config.Labels = make(map[string]string)
-	cw.Config.Labels["type"] = logtype
-
+	cw.Config.Labels = labels
 	u, err := url.ParseQuery(args[1])
 	if err != nil {
 		return errors.Wrapf(err, "while parsing %s", dsn)
@@ -665,7 +667,6 @@ func cwLogToEvent(log *cloudwatchlogs.OutputLogEvent, cfg *LogStreamTailConfig)
 		eventTimestamp := time.Unix(0, *log.Timestamp*int64(time.Millisecond))
 		msg = eventTimestamp.String() + " " + msg
 	}
-
 	l.Raw = msg
 	l.Labels = cfg.Labels
 	l.Time = time.Now()
